@@ -105,7 +105,10 @@ class Entity(object):
     def available_detail(self):
         """Return total number of available lots per room count"""
         result = OrderedDict()
-        result['at'] = self.available_total
+        result['t'] = self.available_total
+
+        result['0'] = len(self.fetch_apartments(available_only=True,
+                                                room_count=1))
         result['1'] = len(self.fetch_apartments(available_only=True,
                                                 room_count=1))
         result['2'] = len(self.fetch_apartments(available_only=True,
